@@ -1,13 +1,19 @@
 """ Module w.r.t. Azure blob storage logic."""
-from dataclasses import dataclass, field
+from dataclasses import dataclass
 from typing import Optional
 
 import pandas as pd
+from azure.core.credentials import (
+    AzureNamedKeyCredential,
+    AzureSasCredential,
+    TokenCredential,
+)
 from azure.core.exceptions import (
     HttpResponseError,
     ServiceRequestError,
     ServiceResponseError,
 )
+from azure.identity import DefaultAzureCredential
 from azure.storage.blob import BlobServiceClient
 
 from warpzone.healthchecks import HealthCheckResult, HealthStatus
@@ -28,8 +34,8 @@ class BlobData:
         cls,
         df: pd.DataFrame,
         name: str,
-        metadata: dict = field(default_factory=dict),
-        schema: dict = None,
+        metadata: Optional[dict] = None,
+        schema: Optional[dict] = None,
     ):
         content = data.pandas_to_parquet(df, schema=schema)
         return cls(content, name, metadata=metadata)
@@ -38,12 +44,27 @@ class BlobData:
         return data.parquet_to_pandas(self.content)
 
 
-class WarpzoneStorageClient:
+class WarpzoneBlobClient:
     """Class to interact with Azure Blob Service"""
 
     def __init__(self, blob_service_client: BlobServiceClient):
         self._blob_service_client = blob_service_client
 
+    @classmethod
+    def from_resource_name(
+        cls,
+        storage_account: str,
+        credential: (
+            AzureNamedKeyCredential | AzureSasCredential | TokenCredential
+        ) = DefaultAzureCredential(),
+    ):
+        blob_service_client = BlobServiceClient(
+            account_url=f"https://{storage_account}.blob.core.windows.net",
+            credential=credential,
+        )
+
+        return cls(blob_service_client)
+
     @classmethod
     def from_connection_string(cls, conn_str: str):
         blob_service_client = BlobServiceClient.from_connection_string(conn_str)
@@ -77,6 +98,44 @@ class WarpzoneStorageClient:
             overwrite=overwrite,
         )
 
+    def delete(self, container_name: str, blob_name: str):
+        container_client = self._blob_service_client.get_container_client(
+            container_name
+        )
+        container_client.delete_blob(blob_name)
+
+    def list_containers(self):
+        return [
+            container.name for container in self._blob_service_client.list_containers()
+        ]
+
+    def list_dir(
+        self,
+        container_name: str,
+        path: str = "",
+        recursive: bool = False,
+    ):
+        container_client = self._blob_service_client.get_container_client(
+            container=container_name,
+        )
+
+        prefix = f"{path}/" if path else ""
+
+        subpaths = []
+        if recursive:
+            for item in container_client.list_blobs(name_starts_with=prefix):
+                if "." in item.name:
+                    subpath = item.name.rstrip("/")
+                    subpaths.append(subpath)
+        else:
+            for item in container_client.walk_blobs(
+                name_starts_with=prefix, delimiter="/"
+            ):
+                subpath = item.name.rstrip("/")
+                subpaths.append(subpath)
+
+        return subpaths
+
     def check_health(self) -> HealthCheckResult:
         """
         Pings the connection to the client's associated storage ressources in Azure.
